#### What is this?

Inspired by [Lumen](https://lumendatabase.org/topics/1) (*formerly Chilling Effects*) and [Google](https://cloud.google.com/storage/docs/dmca), this repo contains the text of DMCA takedown notices and counter-notices we've received here at GitHub. We publish them as they are received, redacting only private information, as well as URLs reported but that we determined were not actionable under the DMCA.


#### Why is this?

In short, we believe that transparency on a specific and ongoing level is essential to good governance. Chilling Effects/Lumen explained it well in 2014 ([archive.org mirror; not present on their current site](https://web.archive.org/web/20140101160724/http://chillingeffects.org/#donato-if:~:text=We%20are%20excited%20about%20the%20new,its%20misuse%20to%20%22chill%22%20legitimate%20activity.)): "We are excited about the new opportunities the Internet offers individuals to express their views . . . but concerned that not everyone feels the same way. Study to date suggests that cease and desist letters often silence Internet users, whether or not their claims have legal merit." (About, ChillingEffects.org, Sept. 2014, licensed under [CC-BY-3.0](http://creativecommons.org/licenses/by/3.0/us/)). Similarly, we post takedown notices here to document their potential to "chill" speech.


#### What does it mean if there's a notice posted here?

It only means that we received the notice on the indicated date. It does ***not*** mean that the content was unlawful or wrong. It does ***not*** mean that the user identified in the notice has done anything wrong. We don't make or imply any judgment about the merit of the claims they make. We post these notices and requests only for informational purposes.

For more details, see our [DMCA policy](https://help.github.com/articles/dmca-takedown-policy/).

#### Anatomy of a takedown notice

In the spirit of transparency, we post each takedown notice that we process without making any changes to the text, except for redacting private information and URLs that were not actionable, and adding a few annotations to help you better understand how we processed the notice. Here are the annotations you might see and what they mean.
1. **We gave repository owners a chance to make changes before we processed the notice.** 

When you see this at the top of a notice (starting in March 2021)
>Before disabling any content in relation to this takedown notice, GitHub
>- contacted the owners of some or all of the affected repositories to give them an opportunity to make changes that could have prevented the need to disable the content 
>- provided information on how to [submit a DMCA Counter Notice](https://docs.github.com/en/articles/guide-to-submitting-a-dmca-counter-notice). 

it means that either the notice did not allege that the entire contents of a repository infringe, or the copyright holder identified other changes that could be made to the content to resolve the alleged infringement. As we note in our [DMCA Takedown Policy](https://docs.github.com/en/github/site-policy/dmca-takedown-policy#a-how-does-this-actually-work), in those cases, because GitHub cannot disable access to specific files within a repository, we will contact the user who created the repository and give them approximately 1 business day to delete or modify the content specified in the notice. 

If the repository owner makes the necessary changes, then GitHub will not disable the content. In some cases, that means the repositories are currently available despite being listed in the notice. In other cases, a repository might be unavailable because the repository owner decided to delete it.

Note, none of this is new policy - what's new as of March 2021 is that we are now adding this annotation in any posted notice we process this way. 

2. **We only processed the takedown notice with respect to some of the reported URLs.** 
>[invalid]

or
>[private]

In many cases a notice alleges copyright infringement in multiple repositories or files. When we determine that only some of the repositories or files are infringing, including where reported content was not available at the time we reviewed the notice, we replace the other URLs with `[invalid]`. Before March 2021, we had replaced those URLs with `[private]`, which we continue to use to note redaction of private information.

3. **The notice reported a repository that's being actively forked.** 

As of March 2021, you may see this note where a takedown notice reports an allegedly infringing repository that was being actively forked at the time it was reported
>[Note: Because the parent repository was actively being forked when this DMCA takedown notice was received, and the submitter had identified all known forks at the time they submitted the takedown notice, GitHub processed the takedown notice against the entire fork network of [x] forks.]

As we explain in our [DMCA Takedown Policy](https://docs.github.com/en/github/site-policy/dmca-takedown-policy#b-what-about-forks-or-whats-a-fork), in those rare cases when a notice alleges copyright infringement in a full repository that is actively being forked, we would process a valid claim against all forks in that network at the time we process the notice, if the notice identified all existing forks of that repository as allegedly infringing. We would do this given the likelihood that all newly created forks would contain the same content as those existing at the time the notice was submitted. 

4. **The notice reported a repository with more than 100 forks.**

As of March 2021, if you see this statement in a notice
>Based on the representative number of forks I have reviewed, I believe that all or most of the forks are infringing to the same extent as the parent repository.

it means the reported network that contains the allegedly infringing content was larger than one hundred (100) repositories and thus would have been difficult to review in its entirety. As a result, we disabled the entire network because the submitter reviewed a representative sample of the forks in the network such that they were fairly certain the entirety of the network was infringing and included that sworn statement as part of their takedown notice. In these cases, we note in the takedown notice the total number of forks we disabled at the time of processing.

#### Contributing

If you are looking to file or dispute a takedown notice by posting to this repository, please STOP :stop_sign: because we do not accept Pull Requests or other contributions to this repository.

Read on to learn about the available paths forward.

If you would just like to comment on a commit to discuss it, that's fine, but again please note that GitHub does not actively monitor comments or other contributions to this repository. So if you want send a comment *to GitHub* for any reason about this repository, please [contact us directly](https://support.github.com/contact).

Please note that re-posting the exact same content that was the subject of a takedown notice without following the proper process ([outlined below](#responding-to-a-dmca-notice)) is a violation of GitHub’s [DMCA Policy](https://docs.github.com/en/github/site-policy/dmca-takedown-policy) and [Terms of Service](https://docs.github.com/en/github/site-policy/github-acceptable-use-policies). If you commit or post content to this repository that violates our Terms of Service, we will delete that content and may suspend access to your account as well.


#### Submitting a DMCA Notice

If you are a copyright owner wishing to submit a takedown notice, read our [DMCA Policy](https://docs.github.com/en/free-pro-team@latest/github/site-policy/dmca-takedown-policy) and [Guide to Submitting a DMCA Takedown Notice](https://docs.github.com/en/free-pro-team@latest/github/site-policy/guide-to-submitting-a-dmca-takedown-notice). You can submit the actual notice using our special [Copyright Claims Contact Form](https://github.com/contact/dmca).


#### Responding to a DMCA Notice

If you are the owner of a repository that has been taken down, you have two main options:

  - Do you want to [make changes](https://docs.github.com/en/free-pro-team@latest/github/site-policy/dmca-takedown-policy#c-what-if-i-inadvertently-missed-the-window-to-make-changes) to the repository that would remove the allegedly infringing content? If that is possible in your case, [contact us](https://support.github.com/contact) to let us know that you would like to make the changes.

  - Do you want to formally dispute the action by [submitting a counter notice](https://docs.github.com/en/free-pro-team@latest/github/site-policy/guide-to-submitting-a-dmca-counter-notice)? Maybe the person sending the takedown notice does not hold the copyright or did not realize that you have a license or made some other mistake in their takedown notice. If you believe your content on GitHub was mistakenly disabled by a DMCA takedown request, you have the right to contest the takedown by [submitting a counter notice](https://docs.github.com/en/free-pro-team@latest/github/site-policy/guide-to-submitting-a-dmca-counter-notice). If you do, we will wait 10-14 days and then re-enable your content unless the copyright owner initiates a legal action before then.

If you do not want to make changes or dispute the notice, but still have general concerns about the copyright laws and how they apply in your case, know that GitHub and developers have the opportunity and a voice to advocate for changes in law and public policy to better support software development. We are constantly looking to [advocate for developers](https://github.blog/category/company/policy/), so feel free to [reach out](https://support.github.com/contact) and let us know your concerns. We also encourage you to [learn more about copyright and speak up](https://docs.github.com/en/free-pro-team@latest/github/site-policy/dmca-takedown-policy#learn-more-and-speak-up) by reaching out to the Copyright Office or your local lawmakers to voice your concerns.
